@@ -521,10 +521,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   151,   151,   150,   166,   165,   202,   201,   224,   223,
-     235,   234,   257,   256,   278,   290,   292,   304,   305,   306,
-     307,   308,   309,   310,   314,   321,   325,   329,   333,   340,
-     340,   351,   351,   362,   368
+       0,   151,   151,   150,   166,   165,   185,   184,   207,   206,
+     218,   217,   240,   239,   261,   273,   275,   287,   288,   289,
+     290,   291,   292,   293,   297,   304,   308,   312,   316,   323,
+     323,   334,   334,   345,   351
 };
 #endif
 
@@ -1475,28 +1475,11 @@ yyreduce:
   case 4:
 #line 166 "policy_parse.y"
     {
-			char *offset_buf;
-
 			p_dir = (yyvsp[(1) - (4)].num);
 			p_type = (yyvsp[(4) - (4)].num);
-
-			/* buffer big enough to hold a prepended negative sign */
-			offset_buf = malloc((yyvsp[(3) - (4)].val).len + 2);
-			if (offset_buf == NULL) 
-			{
-				__ipsec_errcode = EIPSEC_NO_BUFS;
-				return -1;
-			}
-
-			/* positive input value means higher priority, therefore lower
-			   actual value so that is closer to the beginning of the list */
-			sprintf (offset_buf, "-%s", (yyvsp[(3) - (4)].val).buf);
+			p_priority_offset = -atol((yyvsp[(3) - (4)].val).buf);
 
 			errno = 0;
-			p_priority_offset = atol(offset_buf);
-
-			free(offset_buf);
-
 			if (errno != 0 || p_priority_offset < INT32_MIN)
 			{
 				__ipsec_errcode = EIPSEC_INVAL_PRIORITY_OFFSET;
@@ -1511,7 +1494,7 @@ yyreduce:
     break;
 
   case 6:
-#line 202 "policy_parse.y"
+#line 185 "policy_parse.y"
     {
 			p_dir = (yyvsp[(1) - (5)].num);
 			p_type = (yyvsp[(5) - (5)].num);
@@ -1535,7 +1518,7 @@ yyreduce:
     break;
 
   case 8:
-#line 224 "policy_parse.y"
+#line 207 "policy_parse.y"
     {
 			p_dir = (yyvsp[(1) - (4)].num);
 			p_type = (yyvsp[(4) - (4)].num);
@@ -1548,7 +1531,7 @@ yyreduce:
     break;
 
   case 10:
-#line 235 "policy_parse.y"
+#line 218 "policy_parse.y"
     {
 			p_dir = (yyvsp[(1) - (6)].num);
 			p_type = (yyvsp[(6) - (6)].num);
@@ -1572,7 +1555,7 @@ yyreduce:
     break;
 
   case 12:
-#line 257 "policy_parse.y"
+#line 240 "policy_parse.y"
     {
 			p_dir = (yyvsp[(1) - (6)].num);
 			p_type = (yyvsp[(6) - (6)].num);
@@ -1596,7 +1579,7 @@ yyreduce:
     break;
 
   case 14:
-#line 279 "policy_parse.y"
+#line 262 "policy_parse.y"
     {
 			p_dir = (yyvsp[(1) - (1)].num);
 			p_type = 0;	/* ignored it by kernel */
@@ -1609,7 +1592,7 @@ yyreduce:
     break;
 
   case 16:
-#line 292 "policy_parse.y"
+#line 275 "policy_parse.y"
     {
 			if (rule_check() < 0)
 				return -1;
@@ -1622,7 +1605,7 @@ yyreduce:
     break;
 
   case 23:
-#line 310 "policy_parse.y"
+#line 293 "policy_parse.y"
     {
 			__ipsec_errcode = EIPSEC_FEW_ARGUMENTS;
 			return -1;
@@ -1630,7 +1613,7 @@ yyreduce:
     break;
 
   case 24:
-#line 314 "policy_parse.y"
+#line 297 "policy_parse.y"
     {
 			__ipsec_errcode = EIPSEC_FEW_ARGUMENTS;
 			return -1;
@@ -1638,17 +1621,17 @@ yyreduce:
     break;
 
   case 25:
-#line 321 "policy_parse.y"
+#line 304 "policy_parse.y"
     { p_protocol = (yyvsp[(1) - (1)].num); }
     break;
 
   case 26:
-#line 325 "policy_parse.y"
+#line 308 "policy_parse.y"
     { p_mode = (yyvsp[(1) - (1)].num); }
     break;
 
   case 27:
-#line 329 "policy_parse.y"
+#line 312 "policy_parse.y"
     {
 			p_level = (yyvsp[(1) - (1)].num);
 			p_reqid = 0;
@@ -1656,7 +1639,7 @@ yyreduce:
     break;
 
   case 28:
-#line 333 "policy_parse.y"
+#line 316 "policy_parse.y"
     {
 			p_level = IPSEC_LEVEL_UNIQUE;
 			p_reqid = atol((yyvsp[(1) - (1)].val).buf);	/* atol() is good. */
@@ -1664,7 +1647,7 @@ yyreduce:
     break;
 
   case 29:
-#line 340 "policy_parse.y"
+#line 323 "policy_parse.y"
     {
 			p_src = parse_sockaddr(&(yyvsp[(1) - (1)].val), NULL);
 			if (p_src == NULL)
@@ -1673,7 +1656,7 @@ yyreduce:
     break;
 
   case 30:
-#line 346 "policy_parse.y"
+#line 329 "policy_parse.y"
     {
 			p_dst = parse_sockaddr(&(yyvsp[(4) - (4)].val), NULL);
 			if (p_dst == NULL)
@@ -1682,7 +1665,7 @@ yyreduce:
     break;
 
   case 31:
-#line 351 "policy_parse.y"
+#line 334 "policy_parse.y"
     {
 			p_src = parse_sockaddr(&(yyvsp[(1) - (2)].val), &(yyvsp[(2) - (2)].val));
 			if (p_src == NULL)
@@ -1691,7 +1674,7 @@ yyreduce:
     break;
 
   case 32:
-#line 357 "policy_parse.y"
+#line 340 "policy_parse.y"
     {
 			p_dst = parse_sockaddr(&(yyvsp[(5) - (6)].val), &(yyvsp[(6) - (6)].val));
 			if (p_dst == NULL)
@@ -1700,7 +1683,7 @@ yyreduce:
     break;
 
   case 33:
-#line 362 "policy_parse.y"
+#line 345 "policy_parse.y"
     {
 			if (p_dir != IPSEC_DIR_OUTBOUND) {
 				__ipsec_errcode = EIPSEC_INVAL_DIR;
@@ -1710,7 +1693,7 @@ yyreduce:
     break;
 
   case 34:
-#line 368 "policy_parse.y"
+#line 351 "policy_parse.y"
     {
 			if (p_dir != IPSEC_DIR_INBOUND) {
 				__ipsec_errcode = EIPSEC_INVAL_DIR;
@@ -1721,7 +1704,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1725 "policy_parse.c"
+#line 1708 "policy_parse.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1935,7 +1918,7 @@ yyreturn:
 }
 
 
-#line 379 "policy_parse.y"
+#line 362 "policy_parse.y"
 
 
 void
