@@ -1,4 +1,6 @@
-/* $Id: grabmyaddr.c,v 1.23.4.2 2005/07/16 04:41:01 monas Exp $ */
+/*	$NetBSD: grabmyaddr.c,v 1.4.6.3 2008/06/18 07:30:18 mgrooms Exp $	*/
+
+/* Id: grabmyaddr.c,v 1.27 2006/04/06 16:27:05 manubsd Exp */
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -40,7 +42,8 @@
 #if defined(__FreeBSD__) && __FreeBSD__ >= 3
 #include <net/if_var.h>
 #endif
-#if defined(__NetBSD__) || defined(__FreeBSD__)
+#if defined(__NetBSD__) || defined(__FreeBSD__) ||	\
+  (defined(__APPLE__) && defined(__MACH__))
 #include <netinet/in.h>
 #include <netinet6/in6_var.h>
 #endif
@@ -458,6 +461,7 @@ grab_myaddrs()
 	ifconf.ifc_req = iflist;
 	ifconf.ifc_len = len;
 	if (ioctl(s, SIOCGIFCONF, &ifconf) < 0) {
+		close(s);
 		plog(LLV_ERROR, LOCATION, NULL,
 			"ioctl(SIOCGIFCONF) failed: %s\n",
 			strerror(errno));
@@ -722,7 +726,6 @@ autoconf_myaddrsport()
 
 /*
  * get a port number to which racoon binded.
- * NOTE: network byte order returned.
  */
 u_short
 getmyaddrsport(local)
@@ -735,38 +738,23 @@ getmyaddrsport(local)
 	for (p = lcconf->myaddrs; p; p = p->next) {
 		if (!p->addr)
 			continue;
-		if (!cmpsaddrwop(local, p->addr)) {
-			if (! bestmatch) {
-				bestmatch = p;
-				continue;
-			}
-			
-			switch (p->addr->sa_family) {
-			case AF_INET:
-				if (((struct sockaddr_in *)p->addr)->sin_port == PORT_ISAKMP) {
-					bestmatch = p;
-					bestmatch_port = ((struct sockaddr_in *)p->addr)->sin_port;
-					break;
-				}
-				break;
-#ifdef INET6
-			case AF_INET6:
-				if (((struct sockaddr_in6 *)p->addr)->sin6_port == PORT_ISAKMP) {
-					bestmatch = p;
-					bestmatch_port = ((struct sockaddr_in6 *)p->addr)->sin6_port;
-					break;
-				}
-				break;
-#endif
-			default:
-				plog(LLV_ERROR, LOCATION, NULL,
-				     "unsupported AF %d\n", p->addr->sa_family);
-				continue;
-			}
+		if (cmpsaddrwop(local, p->addr))
+			continue;
+
+		/* use first matching address regardless of port */
+		if (!bestmatch) {
+			bestmatch = p;
+			continue;
+		}
+
+		/* matching address with port PORT_ISAKMP */
+		if (extract_port(p->addr) == PORT_ISAKMP) {
+			bestmatch = p;
+			bestmatch_port = PORT_ISAKMP;
 		}
 	}
 
-	return htons(bestmatch_port);
+	return bestmatch_port;
 }
 
 struct myaddrs *
@@ -802,6 +790,12 @@ dupmyaddr(struct myaddrs *old)
 	/* Copy the whole structure and set the differences.  */
 	memcpy (new, old, sizeof (*new));
 	new->addr = dupsaddr (old->addr);
+	if (new->addr == NULL) {
+		plog(LLV_ERROR, LOCATION, NULL,
+			"failed to allocate buffer for myaddrs.\n");
+		racoon_free(new);
+		return NULL;
+	}
 	new->next = old->next;
 	old->next = new;
 
@@ -845,7 +839,7 @@ initmyaddr()
 
 	memset(&nl, 0, sizeof(nl));
 	nl.nl_family = AF_NETLINK;
-	nl.nl_groups = RTMGRP_IPV4_IFADDR|RTMGRP_LINK;
+	nl.nl_groups = RTMGRP_IPV4_IFADDR|RTMGRP_LINK|RTMGRP_IPV6_IFADDR;
 
 	if (bind(lcconf->rtsock, (struct sockaddr*)&nl, sizeof(nl)) < 0) {
 		plog(LLV_ERROR, LOCATION, NULL,
