@@ -1,4 +1,4 @@
-/*	$NetBSD: isakmp_cfg.c,v 1.12.6.3 2008/07/15 02:18:52 mgrooms Exp $	*/
+/*	$NetBSD: isakmp_cfg.c,v 1.12.6.4 2008/11/27 15:25:20 vanhu Exp $	*/
 
 /* Id: isakmp_cfg.c,v 1.55 2006/08/22 18:17:17 manubsd Exp */
 
@@ -2054,7 +2054,7 @@ isakmp_cfg_resize_pool(size)
 	/* If a pool already exists, check if we can shrink it */
 	if ((isakmp_cfg_config.port_pool != NULL) &&
 	    (size < isakmp_cfg_config.pool_size)) {
-		for (i = isakmp_cfg_config.pool_size; i >= size; --i) {
+		for (i = isakmp_cfg_config.pool_size-1; i >= size; --i) {
 			if (isakmp_cfg_config.port_pool[i].used) {
 				plog(LLV_ERROR, LOCATION, NULL, 
 				    "resize pool from %zu to %d impossible "
@@ -2147,10 +2147,12 @@ isakmp_cfg_init(cold)
 	isakmp_cfg_config.splitdns_list = NULL;
 	isakmp_cfg_config.splitdns_len = 0;
 
+#if 0
 	if (cold == ISAKMP_CFG_INIT_COLD) {
 		if ((error = isakmp_cfg_resize_pool(ISAKMP_CFG_MAX_CNX)) != 0)
 			return error;
 	}
+#endif
 
 	return 0;
 }
