@@ -1,3 +1,5 @@
+/*	$NetBSD: setkey.c,v 1.11.6.2 2009/08/06 04:45:16 tteras Exp $	*/
+
 /*	$KAME: setkey.c,v 1.36 2003/09/24 23:52:51 itojun Exp $	*/
 
 /*
@@ -42,11 +44,7 @@
 #include <err.h>
 #include <netinet/in.h>
 #include <net/pfkeyv2.h>
-#ifdef HAVE_NETINET6_IPSEC
-#  include <netinet6/ipsec.h>
-#else 
-#  include <netinet/ipsec.h>
-#endif
+#include PATH_IPSEC_H
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -316,8 +314,7 @@ stdin_loop()
 #else
 		char rbuf[1024];
 		rbuf[0] = '\0';
-		fgets (rbuf, sizeof(rbuf), stdin);
-		if (!rbuf[0])
+		if (fgets(rbuf, sizeof(rbuf), stdin) == NULL)
 			break;
 		if (rbuf[strlen(rbuf)-1] == '\n')
 			rbuf[strlen(rbuf)-1] = '\0';
